@@ -191,7 +191,7 @@ class DuPanClient:
         scan_in_console: bool = True, 
     ):
         self.__dict__["session"] = session = Session()
-        session.headers["User-Agent"] = "pan.baidu.com"
+        session.headers["User-Agent"] = "Mozilla/5.0"
         for _ in range(2):
             if not cookie or "BDUSS=" not in cookie:
                 self.login_with_qrcode(scan_in_console=scan_in_console)
